#undef PACKAGE
#undef VERSION
#undef HAVE_GETTEXT
#undef ENABLE_NLS
#undef GETTEXT_PACKAGE
#undef GNOME_DB_EXPLICIT_TRANSLATION_DOMAIN
#undef BUILD_CAPPLET
